from distutils.core import setup
setup(
  name = 'rbcz',
  packages = ['rbcz'],
  version = '0.1',
  description = 'library for interacting with Czech Raiffeisen Bank\'s text bank statements',
  author = 'Sean McLemon',
  author_email = 'sean.mclemon@gmail.com',
  url = 'https://github.com/smcl/rbcz.py',
  download_url = 'https://github.com/smcl/rbcz.py/tarball/0.1',
  keywords = ['banking', 'raiffeisen', 'czech', 'cz'],
  classifiers = [],
)
